@@ -1,3 +1,5 @@
+from Namespace import Namespace
+import json
 import http.client
 from rci.Exceptions import RciError
 
@@ -10,7 +12,7 @@ class Client:
     resp = self.conn.getresponse()
     if resp.status != 200:
       raise RciNetworkError()
-    return resp.read()
+    return Namespace.json(resp.read())
 
   def close(self):
     self.conn.close()
